@@ -7,11 +7,12 @@ import textwrap
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Tuple, Union
 
-import pycountry
 import requests
+from langcodes import Language
 from pyd2v import D2V
 from pymediainfo import MediaInfo, Track
 
+from pynfogen.constants import DYNAMIC_RANGE_MAP
 from pynfogen.formatter import CustomFormats
 
 
@@ -311,22 +312,32 @@ class NFO:
                     fp = os.path.splitext(self.file)[0] + "." + ext
                     if os.path.exists(fp):
                         os.unlink(fp)
+
+            if video.hdr_format:
+                range_ = " ".join([DYNAMIC_RANGE_MAP.get(x) for x in video.hdr_format.split(" / ")])
+            elif "HLG" in ((video.transfer_characteristics or ""), (video.transfer_characteristics_original or "")):
+                range_ = "HLG"
+            else:
+                range_ = "SDR"
+
             line_1 = "- {language}, {codec} ({profile}) {width}x{height} ({aspect}) @ {bitrate}".format(
-                language=pycountry.languages.get(alpha_2=video.language).name,
+                language=Language.get(video.language).display_name(),
                 codec=codec,
                 profile=video.format_profile,
                 width=video.width, height=video.height,
                 aspect=video.other_display_aspect_ratio[0],
                 bitrate=f"{video.other_bit_rate[0]}{f' ({video.bit_rate_mode})' if video.bit_rate_mode else ''}"
             )
-            line_2 = "  {fps} FPS ({fps_mode}), {color_space}{subsampling}P{bit_depth}, {scan}".format(
+            line_2 = "  {fps} FPS ({fps_mode}), {color_space}{subsampling}P{bit_depth}, {range}, {scan}".format(
                 fps=f"{video.framerate_num}/{video.framerate_den}" if video.framerate_num else video.frame_rate,
                 fps_mode="VFR" if vst else video.frame_rate_mode,
                 color_space=video.color_space,
                 subsampling=video.chroma_subsampling.replace(":", ""),
                 bit_depth=video.bit_depth,
+                range=range_,
                 scan=scan_overview
             )
+
             data.append([line_1, line_2])
         return data
 
@@ -338,7 +349,7 @@ class NFO:
             if t.title and "Commentary" in t.title:
                 title = t.title
             else:
-                title = pycountry.languages.get(alpha_2=t.language).name
+                title = Language.get(t.language).display_name()
             if t.channel_layout:
                 channels = float(sum(self.AUDIO_CHANNEL_LAYOUT_WEIGHT.get(x, 1) for x in t.channel_layout.split(" ")))
             else:
@@ -378,7 +389,7 @@ class NFO:
             # | es / Spanish | Spanish (Latin American, SDH) | - Spanish (Latin American, SDH), SubRip (SRT) |
             # | es / Spanish | Latin American (SDH)          | - Spanish, Latin American (SDH), SubRip (SRT) |
             # | es / Spanish | None                          | - Spanish, SubRip (SRT)                       |
-            language = pycountry.languages.get(alpha_2=sub.language).name
+            language = Language.get(sub.language).display_name()
             if sub.title:
                 if language.lower() in sub.title.lower():
                     line_items.append(sub.title)
